====
CADA
====

CADA is a method for the phenotype-based prioritization of variatns.

.. toctree::
    :hidden:
    :maxdepth: 1
    :caption: Contents

    installation

.. toctree::
    :hidden:
    :maxdepth: 1
    :caption: Project Info

    contributing
    authors
    history

.. toctree::
    :hidden:
    :maxdepth: 1
    :caption: CLI

    cli

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
